#!/bin/bash
# This script configures .deb based Linux repositories
# License: public domain
# Script https://github.com/open-eid/linux-installer
# See wiki https://github.com/open-eid/linux-installer/wiki/Linux-Packages
set -e

# Script was Modified For upload in OBS 

test_sudo() {
  if ! command -v sudo>/dev/null; then
     make_fail "You must have sudo and be in sudo group\nAs root do: apt-get install sudo && adduser $USER sudo"
  fi
}

test_root() {
  if test $(id -u) -eq 0; then
    echo "You run this script as root. DO NOT RUN RANDOM SCRIPTS AS ROOT."
    exit 2
  fi
}

make_install() {
  echo "Installing software (apt-get update && apt-get install open-eid)"
  sudo apt-get update
  sudo apt-get install opensc "$@"
}

make_fail() {
  echo -e "$1"
  exit 3
}

make_warn() {
  echo "### $1"
  echo "Press ENTER to continue, CTRL-C to cancel"
  read -r dummy
}

### Install Estonian ID card software

# check for Debian derivative.
if ! command -v lsb_release>/dev/null; then
  make_fail "# Not a Debian Linux :("
fi

# we use sudo
test_root
test_sudo

make_install open-eid chrome-token-signing-policy
# Configure Chrome PKCS11 driver for current user, /etc/xdg/autstart/ will init other users on next logon
/usr/bin/esteid-update-nssdb
echo -e "\n\nThank you for using Estonian ID card!"
